@@ -1,5 +1,4 @@
 #include <SndObj/AudioDefs.h>
-#include "../PVBlur.h"
 #include <stdio.h>
 
 void Usage(char* progr);
@@ -19,8 +18,14 @@ main(int argc, char** argv){
  exit(1);
  }
 
-SndRTIO input(1, SND_INPUT, 512);
-SndRTIO output(1, SND_OUTPUT, 512);
+#ifndef MACOSX
+SndRTIO output(1, SND_OUTPUT);
+SndRTIO input(1, SND_INPUT);
+#else
+SndCoreAudio io(1);
+#define input io
+#define output io
+#endif
 
  HammingTable window(1024, 0.54f);
 
@@ -31,7 +36,7 @@ SndRTIO output(1, SND_OUTPUT, 512);
 
  output.SetOutput(1, &synth);
  
- int end = dur*DEF_SR/DEF_VECSIZE;
+ int end = (int)(dur*DEF_SR/DEF_VECSIZE);
  
  for(int i=0; i<end; i++){ 
 
